Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(595)

Unified Diff: ios/web/web_state/web_state_delegate_stub.h

Issue 2614023006: [ios] Removed -[CRWWebDelegate openURLWithParams:]. (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/web/web_state/web_state_delegate_stub.h
diff --git a/ios/web/web_state/web_state_delegate_stub.h b/ios/web/web_state/web_state_delegate_stub.h
index 7398dca818bb77daf468e865a0cb737079ef66d9..262ccc0edd6ac03e71ea46c8a2cd01d1f38e95fa 100644
--- a/ios/web/web_state/web_state_delegate_stub.h
+++ b/ios/web/web_state/web_state_delegate_stub.h
@@ -11,7 +11,10 @@
// Stub implementation for CRWWebStateDelegate protocol.
@interface CRWWebStateDelegateStub
: OCMockComplexTypeHelper<CRWWebStateDelegate>
-// web::WebState received in delegate method calls..
+// web::WebState::OpenURLParams in |webState:openURLWithParams:| call.
+@property(nonatomic, readonly)
+ const web::WebState::OpenURLParams* openURLParams;
+// web::WebState received in delegate method calls.
@property(nonatomic, readonly) web::WebState* webState;
// Progress received in |webState:didChangeProgress| call.
@property(nonatomic, readonly) double changedProgress;
« no previous file with comments | « ios/web/web_state/web_state_delegate_bridge_unittest.mm ('k') | ios/web/web_state/web_state_delegate_stub.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698